# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class TwitterWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # Fetch tweet detail | 获取推文详情
    async def fetch_tweet_detail(self, tweet_id: str):
        endpoint = "/api/v1/twitter/web/fetch_tweet_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?tweet_id={tweet_id}")
        return data

    # Fetch user profile | 获取用户资料
    async def fetch_user_profile(self, screen_name: str = None, rest_id: int = None):
        endpoint = "/api/v1/twitter/web/fetch_user_profile"
        params = []
        if screen_name:
            params.append(f"screen_name={screen_name}")
        if rest_id:
            params.append(f"rest_id={rest_id}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch user post tweet | 获取用户发帖
    async def fetch_user_post_tweet(self, screen_name: str = None, rest_id: int = None, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_post_tweet"
        params = []
        if screen_name:
            params.append(f"screen_name={screen_name}")
        if rest_id:
            params.append(f"rest_id={rest_id}")
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch search timeline | 搜索
    async def fetch_search_timeline(self, keyword: str, search_type: str = "Top", cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_search_timeline"
        params = [f"keyword={keyword}", f"search_type={search_type}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch post comments | 获取评论
    async def fetch_post_comments(self, tweet_id: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_post_comments"
        params = [f"tweet_id={tweet_id}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch latest post comments | 获取最新的推文评论
    async def fetch_latest_post_comments(self, tweet_id: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_latest_post_comments"
        params = [f"tweet_id={tweet_id}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch user tweet replies | 获取用户推文回复
    async def fetch_user_tweet_replies(self, screen_name: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_tweet_replies"
        params = [f"screen_name={screen_name}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch user highlights tweets | 获取用户高光推文
    async def fetch_user_highlights_tweets(self, user_id: str, count: int = 20, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_highlights_tweets"
        params = [f"userId={user_id}", f"count={count}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch user media | 获取用户媒体
    async def fetch_user_media(self, screen_name: str = None, rest_id: int = None):
        endpoint = "/api/v1/twitter/web/fetch_user_media"
        params = []
        if screen_name:
            params.append(f"screen_name={screen_name}")
        if rest_id:
            params.append(f"rest_id={rest_id}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch retweet user list | 转推用户列表
    async def fetch_retweet_user_list(self, tweet_id: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_retweet_user_list"
        params = [f"tweet_id={tweet_id}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch trending | 趋势
    async def fetch_trending(self, country: str = "UnitedStates"):
        endpoint = "/api/v1/twitter/web/fetch_trending"
        data = await self.client.fetch_get_json(f"{endpoint}?country={country}")
        return data

    # Fetch user followings | 用户关注
    async def fetch_user_followings(self, screen_name: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_followings"
        params = [f"screen_name={screen_name}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data

    # Fetch user followers | 用户粉丝
    async def fetch_user_followers(self, screen_name: str, cursor: str = None):
        endpoint = "/api/v1/twitter/web/fetch_user_followers"
        params = [f"screen_name={screen_name}"]
        if cursor:
            params.append(f"cursor={cursor}")
        query = "&".join(params)
        data = await self.client.fetch_get_json(f"{endpoint}?{query}")
        return data




# Import API SDK Client class
from tikhub.http_client.api_client import APIClient


class BilibiliWeb:

    # Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # Fetch single video data | 获取单个视频详情信息
    async def fetch_one_video(self, bv_id: str):
        endpoint = "/api/v1/bilibili/web/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}")
        return data

    # Fetch video playurl | 获取视频流地址
    async def fetch_video_playurl(self, bv_id: str, cid: str):
        endpoint = "/api/v1/bilibili/web/fetch_video_playurl"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}&cid={cid}")
        return data

    # Fetch user post videos | 获取用户发布视频作品数据
    async def fetch_user_post_videos(self, uid: str, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_user_post_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&pn={pn}")
        return data

    # Fetch collection folders | 获取用户所有收藏夹信息
    async def fetch_collect_folders(self, uid: str):
        endpoint = "/api/v1/bilibili/web/fetch_collect_folders"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}")
        return data

    # Fetch videos from collection folder | 获取指定收藏夹内视频数据
    async def fetch_user_collection_videos(self, folder_id: str, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_user_collection_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?folder_id={folder_id}&pn={pn}")
        return data

    # Fetch user profile | 获取指定用户的信息
    async def fetch_user_profile(self, uid: str):
        endpoint = "/api/v1/bilibili/web/fetch_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}")
        return data

    # Fetch comprehensive popular videos | 获取综合热门视频信息
    async def fetch_com_popular(self, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_com_popular"
        data = await self.client.fetch_get_json(f"{endpoint}?pn={pn}")
        return data

    # Fetch video comments | 获取指定视频的评论
    async def fetch_video_comments(self, bv_id: str, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_video_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}&pn={pn}")
        return data

    # Fetch comment reply | 获取视频下指定评论的回复
    async def fetch_comment_reply(self, bv_id: str, rpid: str, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_comment_reply"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}&pn={pn}&rpid={rpid}")
        return data

    # Fetch user dynamics | 获取指定用户动态
    async def fetch_user_dynamic(self, uid: str, offset: str = ""):
        endpoint = "/api/v1/bilibili/web/fetch_user_dynamic"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&offset={offset}")
        return data

    # Fetch video danmaku | 获取视频实时弹幕
    async def fetch_video_danmaku(self, cid: str):
        endpoint = "/api/v1/bilibili/web/fetch_video_danmaku"
        data = await self.client.fetch_get_json(f"{endpoint}?cid={cid}")
        return data

    # Fetch live room details | 获取指定直播间信息
    async def fetch_live_room_detail(self, room_id: str):
        endpoint = "/api/v1/bilibili/web/fetch_live_room_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}")
        return data

    # Fetch live room videos | 获取指定直播间视频流
    async def fetch_live_videos(self, room_id: str):
        endpoint = "/api/v1/bilibili/web/fetch_live_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}")
        return data

    # Fetch live streamers in area | 获取指定分区正在直播的主播
    async def fetch_live_streamers(self, area_id: str, pn: int = 1):
        endpoint = "/api/v1/bilibili/web/fetch_live_streamers"
        data = await self.client.fetch_get_json(f"{endpoint}?area_id={area_id}&pn={pn}")
        return data

    # Fetch all live areas | 获取所有直播分区列表
    async def fetch_all_live_areas(self):
        endpoint = "/api/v1/bilibili/web/fetch_all_live_areas"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # Convert bv_id to aid | 通过bv号获得视频aid号
    async def bv_to_aid(self, bv_id: str):
        endpoint = "/api/v1/bilibili/web/bv_to_aid"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}")
        return data

    # Fetch video parts by bv_id | 通过bv号获得视频分p信息
    async def fetch_video_parts(self, bv_id: str):
        endpoint = "/api/v1/bilibili/web/fetch_video_parts"
        data = await self.client.fetch_get_json(f"{endpoint}?bv_id={bv_id}")
        return data
